Type Definition xxcalc::evaluator::FunctionHandle [−] [src]

type FunctionHandle = Box<Fn(Vec<Polynomial>) -> Result<Polynomial, EvaluationError>>;

Pointer to function processing Polynomial arguments.

Such function takes a defined number of Polynomial arguments and transform them into a single Polynomial value. It is used to implement operators and other functions in the evaluator.